pygeodesy.namedTuples.Vector4Tuple

Package pygeodesy :: Module namedTuples :: Class Vector4Tuple |
[frames] | no frames]

# Class Vector4Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       Vector4Tuple

Known Subclasses:
  - triaxials.triaxial3.Cartesian5Tuple

4-Tuple `(x, y, z, h)` of (geocentric) components, all in `meter` or the same `units`.

Instance Methods
to3Tuple(self) Reduce this Vector4Tuple to a Vector3Tuple. |
toCartesian(self, Cartesian, **Cartesian_kwds) Return this `Vector4Tuple` as a `Cartesian`. |
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
| xyz Get X, Y and Z components (Vector3Tuple).
| xyz3 Get X, Y and Z components as `3-tuple`.
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### to3Tuple (self) |
Reduce this Vector4Tuple to a Vector3Tuple. Returns: A Vector3Tuple`(x, y, z)`.

### toCartesian (self, Cartesian, **Cartesian_kwds) |
Return this `Vector4Tuple` as a `Cartesian`. Arguments: `Cartesian` - The `Cartesian` class to use. `Cartesian_kwds` - Optional, additional `Cartesian` keyword arguments. Returns: The `Cartesian` instance.

Property Details

### xyz Get X, Y and Z components (Vector3Tuple). Get method: xyz(self) - Get X, Y and Z components (Vector3Tuple). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### xyz3 Get X, Y and Z components as `3-tuple`. Get method: xyz3(self) - Get X, Y and Z components as `3-tuple`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.